# /packages/intranet-trans-project-feedback/lib/survey-component.tcl
#
# Copyright (C) 2015 Project Open Business Solutions S.L.
#
# This program is free software. You can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation;
# either version 2 of the License, or (at your option)
# any later version. This program is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.

# Profiles represent OpenACS groups used by ]project-open[
# However, for performance reasons we have introduced special
# caching and auxillary functions specific to ]po[.

# @author klaus.hofeditz@project-open.com
# @author philg@mit.edu
# @author nstrug@arsdigita.com

# ---------------------------------------------------------------------------
# DEFAULTS & PERMISSIONS 
# ---------------------------------------------------------------------------

set current_url [ns_conn url]
set current_user_id [ad_maybe_redirect_for_registration]
set package_url "/simple-survey"
if { ![info exists return_url] || ""==$return_url } { set return_url "/intranet/projects/view?project_id=$project_id" }

im_project_permissions $current_user_id $project_id view read write admin
if {!$read} { return "" }

set survey_id [db_string get_data "select survey_id from survsimp_surveys where name = 'Project Translation Feedback'" -default 0]
if { 0 == $survey_id } {return [lang::message::lookup "" intranet-trans-project-feedback.SurveyNotFound "Survey 'Project Translation Feedback' not found"] }
# ad_require_permission $survey_id survsimp_take_survey

# ---------------------------------------------------------------------------
# Show Survey
# ---------------------------------------------------------------------------

db_1row survey_info "
	select 
		name, 
		description, 
		single_response_p, 
		single_editable_p, 
		display_type
    	from 
		survsimp_surveys 
	where 
		survey_id = :survey_id"

set context [list [list "./" "Surveys"] "$name"]

set num_responses [db_string responses_count {
    select count(response_id)
    from survsimp_responses, acs_objects
    where response_id = object_id
    and survey_id = :survey_id
}]


if {$single_response_p == "t"} {
    if {$num_responses == "0"} {
        set button_label "Submit response"
        set edit_previous_response_p "f"
    } else {
        set button_label "Modify submited response"
        set edit_previous_response_p "t"
    }
    set previous_responses_link ""
} else {
    set button_label "Submit response"
    set edit_previous_response_p "f"
    if {$num_responses == "0"} {
        set previous_response_p "f"
    } else {
        set previous_response_p "t"
    }
}

if {$single_response_p == "t" && $single_editable_p == "f"} {
    set modification_allowed_p "f"
} else {
    set modification_allowed_p "t"
}

# build a list containing the HTML (generated with survsimp_question_display) for each question
set rownum 0

set questions [list]

db_foreach question_ids_select {
    select question_id
    from survsimp_questions
    where survey_id = :survey_id
    and active_p = 't'
    order by sort_key
} {
    append html "[survsimp_question_display_trans_feedback $question_id $project_id $edit_previous_response_p]<br/><br/>"
}


